aboutsummaryrefslogtreecommitdiffstats
path: root/extcap.h
diff options
context:
space:
mode:
Diffstat (limited to 'extcap.h')
-rw-r--r--extcap.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/extcap.h b/extcap.h
index 578d2162d1..867c34ffc0 100644
--- a/extcap.h
+++ b/extcap.h
@@ -22,6 +22,7 @@
#include <wsutil/plugins.h>
+#include "capture/capture_session.h"
#include <ui/capture_ui_utils.h>
/* As boolean flags will be allowed any form of yes, true or any number != 0 (or starting with 0)
@@ -205,22 +206,23 @@ extcap_has_configuration(const char * ifname, gboolean is_required);
gboolean
extcap_has_toolbar(const char *ifname);
+#ifdef HAVE_LIBPCAP
/**
* Initializes each extcap interface with the supplied capture options.
* Initializes the extcap interface list if that hasn't already been done.
- * @param capture_opts Capture options.
+ * @param cap_session Capture session.
* @return TRUE on success, FALSE on failure.
*/
gboolean
-extcap_init_interfaces(capture_options * capture_opts);
+extcap_init_interfaces(capture_session *cap_session);
+#endif /* HAVE_LIBPCAP */
/**
* Clean up all if related stuff.
- * @param capture_opts Capture options.
- * @param errormsg Set to NULL on success, error description on failure.
+ * @param cap_session Capture session.
*/
void
-extcap_if_cleanup(capture_options * capture_opts, gchar ** errormsg);
+extcap_if_cleanup(capture_session *cap_session);
/**
* Fetch an extcap preference for a given argument.
@@ -205,22 +206,23 @@ extcap_has_configuration(const char * ifname, gboolean is_required);
/**
- * Initializes each extcap interface with the supplied capture options.
+ * Initializes each extcap interface with the supplied capture session.
* Initializes the extcap interface list if that hasn't already been done.